#! /usr/bin/env python3
import click
from sqlalchemy import create_engine, desc
from sqlalchemy.orm import sessionmaker
from schmeckels.models import Transaction
from schmeckels.helper import get_session
import sys
from schmeckels import banks


@click.command(name="import")
@click.option("--filetype", "-t", type=click.Choice(["dkb", "sparkasse-mt940", "bunq-csv"], case_sensitive=False))
@click.option("--profile", "-p")
@click.option("--force", "-f", default=False, is_flag=True)
@click.argument("filename", type=click.Path(exists=True))
def command(filename, profile, force, filetype):
    session = get_session(profile)

    latest = session.query(Transaction).order_by(desc(Transaction.date)).first()
    new = []

    if filetype == "sparkasse-mt940":
        bank = banks.Sparkasse_MT940(filename)
    elif filetype == "bunq-csv":
        bank = banks.Bunq(filename)
    elif filetype == "dkb":
        bank = banks.DKB(filename)

    for t in bank.get_transactions():
        if not force and latest and t.date < latest.date:
            print("Found a transaction older than then newest transction in the DB.")
            print("If you are sure that you want to import this file, use --force")
            sys.exit(1)

        new.append(t)
        print(".", end="", flush=True)

    session.bulk_save_objects(new)
    session.commit()
    print(f"Imported {len(new)} transactions")
